@@ -1,7 +1,8 @@
 
 require 5;
 package Pod::Simple::DumpAsText;
-$VERSION = '2.29_4';
+$VERSION = '2.01';
+use utf8;
 use Pod::Simple ();
 BEGIN {@ISA = ('Pod::Simple')}
 
@@ -16,7 +17,6 @@ sub new {
   my $new = $self->SUPER::new(@_);
   $new->{'output_fh'} ||= *STDOUT{IO};
   $new->accept_codes('VerbatimFormatted');
-  $new->keep_encoding_directive(1);
   return $new;
 }
 
@@ -54,7 +54,7 @@ sub _handle_text {
          [^\n]{55}         # Snare some characters from a line
          [^\n\ ]{0,50}     #  and finish any current word
         )
-        \ {1,10}(?!\n)     # capture some spaces not at line-end
+        \x20{1,10}(?!\n)   # capture some spaces not at line-end
        /$1"\n$indent . "/gx     # => line-break here
     ;
     
@@ -112,22 +112,9 @@ L<Pod::Simple::DumpAsXML>
 
 L<Pod::Simple>
 
-=head1 SUPPORT
-
-Questions or discussion about POD and Pod::Simple should be sent to the
-pod-people@perl.org mail list. Send an empty email to
-pod-people-subscribe@perl.org to subscribe.
-
-This module is managed in an open GitHub repository,
-L<https://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/theory/pod-simple.git> and send patches!
-
-Patches against Pod::Simple are welcome. Please send bug reports to
-<bug-pod-simple@rt.cpan.org>.
-
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -138,19 +125,7 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Pod::Simple was created by Sean M. Burke <sburke@cpan.org>.
-But don't bother him, he's retired.
-
-Pod::Simple is maintained by:
-
-=over
-
-=item * Allison Randal C<allison@perl.org>
-
-=item * Hans Dieter Pearcey C<hdp@cpan.org>
-
-=item * David E. Wheeler C<dwheeler@cpan.org>
-
-=back
+Sean M. Burke C<sburke@cpan.org>
 
 =cut
+
