@@ -2,13 +2,10 @@
 require 5;
 package Pod::Simple::LinkSection;
   # Based somewhat dimly on Array::Autojoin
-use vars qw($VERSION );
-$VERSION = '2.29_4';
 
 use strict;
+use utf8;
 use Pod::Simple::BlackBox;
-use vars qw($VERSION );
-$VERSION = '2.29_4';
 
 use overload( # So it'll stringify nice
   '""'   => \&Pod::Simple::BlackBox::stringify_lol,
@@ -114,7 +111,7 @@ Output:
                           ], 'Pod::Simple::LinkSection' ),
                    'baz'
                  ], 'Pod::Simple::LinkSection' );
-
+  
 But stringify it and you get just the text content:
 
   % perl -MData::Dumper -e
@@ -130,22 +127,9 @@ Output:
 
 L<Pod::Simple>
 
-=head1 SUPPORT
-
-Questions or discussion about POD and Pod::Simple should be sent to the
-pod-people@perl.org mail list. Send an empty email to
-pod-people-subscribe@perl.org to subscribe.
-
-This module is managed in an open GitHub repository,
-L<https://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/theory/pod-simple.git> and send patches!
-
-Patches against Pod::Simple are welcome. Please send bug reports to
-<bug-pod-simple@rt.cpan.org>.
-
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2004 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -156,19 +140,7 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Pod::Simple was created by Sean M. Burke <sburke@cpan.org>.
-But don't bother him, he's retired.
-
-Pod::Simple is maintained by:
-
-=over
-
-=item * Allison Randal C<allison@perl.org>
-
-=item * Hans Dieter Pearcey C<hdp@cpan.org>
-
-=item * David E. Wheeler C<dwheeler@cpan.org>
-
-=back
+Sean M. Burke C<sburke@cpan.org>
 
 =cut
+
