@@ -1,11 +1,13 @@
 
+
 require 5;
 package Pod::Simple::SimpleTree;
 use strict;
+use utf8;
 use Carp ();
 use Pod::Simple ();
 use vars qw( $ATTR_PAD @ISA $VERSION $SORT_ATTRS);
-$VERSION = '2.29_4';
+$VERSION = '2.01';
 BEGIN {
   @ISA = ('Pod::Simple');
   *DEBUG = \&Pod::Simple::DEBUG unless defined &DEBUG;
@@ -66,15 +68,15 @@ Pod::Simple::SimpleTree -- parse Pod into a simple parse tree
 =head1 SYNOPSIS
 
   % cat ptest.pod
-
+  
   =head1 PIE
-
+  
   I like B<pie>!
-
+  
   % perl -MPod::Simple::SimpleTree -MData::Dumper -e \
      "print Dumper(Pod::Simple::SimpleTree->new->parse_file(shift)->root)" \
      ptest.pod
-
+  
   $VAR1 = [
             'Document',
             { 'start_line' => 1 },
@@ -120,7 +122,7 @@ the form: C<[ I<elementname>, \%attributes, I<...subnodes...> ]>.
 See the example tree dump in the Synopsis, above.
 
 Every text node in the tree is represented by a simple (non-ref)
-string scalar.  So you can test C<ref($node)> to see whether you have
+string scalar.  So you can test C<ref($node)> to see whather you have
 an element node or just a text node.
 
 The top node in the tree is C<[ 'Document', \%attributes,
@@ -135,22 +137,9 @@ L<perllol>
 
 L<The "Tree" subsubsection in XML::Parser|XML::Parser/"Tree">
 
-=head1 SUPPORT
-
-Questions or discussion about POD and Pod::Simple should be sent to the
-pod-people@perl.org mail list. Send an empty email to
-pod-people-subscribe@perl.org to subscribe.
-
-This module is managed in an open GitHub repository,
-L<https://github.com/theory/pod-simple/>. Feel free to fork and contribute, or
-to clone L<git://github.com/theory/pod-simple.git> and send patches!
-
-Patches against Pod::Simple are welcome. Please send bug reports to
-<bug-pod-simple@rt.cpan.org>.
-
 =head1 COPYRIGHT AND DISCLAIMERS
 
-Copyright (c) 2002 Sean M. Burke.
+Copyright (c) 2002 Sean M. Burke.  All rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
@@ -161,19 +150,7 @@ merchantability or fitness for a particular purpose.
 
 =head1 AUTHOR
 
-Pod::Simple was created by Sean M. Burke <sburke@cpan.org>.
-But don't bother him, he's retired.
-
-Pod::Simple is maintained by:
-
-=over
-
-=item * Allison Randal C<allison@perl.org>
-
-=item * Hans Dieter Pearcey C<hdp@cpan.org>
-
-=item * David E. Wheeler C<dwheeler@cpan.org>
-
-=back
+Sean M. Burke C<sburke@cpan.org>
 
 =cut
+
